@@ -2,9 +2,10 @@ import tsai
 from .imports import *
 from .utils import *
 from .data.all import *
+from .losses import *
 from .metrics import *
 from .learner import *
+from .tslearner import *
 from .optimizer import *
 from .models.all import *
-from .trading.all import *
 from .callback.all import *
\ No newline at end of file
